Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(262)

Unified Diff: components/metrics/metrics_service.h

Issue 1548113002: Switch to standard integer types in components/, part 2 of 4. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: gn Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/metrics/metrics_reporting_scheduler_unittest.cc ('k') | components/metrics/metrics_service.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/metrics/metrics_service.h
diff --git a/components/metrics/metrics_service.h b/components/metrics/metrics_service.h
index 0939c139bd2a17e6dcb7781ab9359d8af6a130b8..ce4102b8dfa36408fe037bd6772184d759a48a4e 100644
--- a/components/metrics/metrics_service.h
+++ b/components/metrics/metrics_service.h
@@ -8,12 +8,14 @@
#ifndef COMPONENTS_METRICS_METRICS_SERVICE_H_
#define COMPONENTS_METRICS_METRICS_SERVICE_H_
+#include <stdint.h>
+
#include <map>
#include <string>
#include <vector>
-#include "base/basictypes.h"
#include "base/gtest_prod_util.h"
+#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/memory/scoped_vector.h"
#include "base/memory/weak_ptr.h"
@@ -23,6 +25,7 @@
#include "base/metrics/user_metrics.h"
#include "base/observer_list.h"
#include "base/time/time.h"
+#include "build/build_config.h"
#include "components/metrics/clean_exit_beacon.h"
#include "components/metrics/metrics_log.h"
#include "components/metrics/metrics_log_manager.h"
@@ -111,11 +114,11 @@ class MetricsService : public base::HistogramFlattener {
std::string GetClientId();
// Returns the install date of the application, in seconds since the epoch.
- int64 GetInstallDate();
+ int64_t GetInstallDate();
// Returns the date at which the current metrics client ID was created as
- // an int64 containing seconds since the epoch.
- int64 GetMetricsReportingEnabledDate();
+ // an int64_t containing seconds since the epoch.
+ int64_t GetMetricsReportingEnabledDate();
// Returns true if the last session exited cleanly.
bool WasLastShutdownClean() const;
« no previous file with comments | « components/metrics/metrics_reporting_scheduler_unittest.cc ('k') | components/metrics/metrics_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698